<TS version="2.1" language="zh">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">右键单击来编辑地址或者标签</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">创建新地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">新建(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">复制当前选中的地址到系统剪贴板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">复制(&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">关闭(&amp;L)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">从列表中删除当前已选地址</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">输入要搜索的地址或标签</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">将当前选项卡中的数据导出到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">导出(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">删除(&amp;D)</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">选择收款人地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">选择接收比特币地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">选择(&amp;H)</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">这些是你的比特币支付地址。在发送之前，一定要核对金额和接收地址。</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">你将使用下列比特币地址接受付款。选取收款选项卡中 “产生新收款地址” 按钮来生成新地址。
签名只能使用“传统”类型的地址。</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">复制 &amp;标签</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">出口地址列表</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">逗号分隔文件</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">试图将地址列表保存到 %1时出错，请再试一次。</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">付款地址 - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">收款地址 - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">导出失败</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(无标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">密码对话框</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">输入密码</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">新的密码</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">重复新密码</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">显示密码</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">加密钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">该操作需要您的钱包密码来解锁钱包。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">打开钱包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">修改密码</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">确认钱包加密</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">注意: 如果你忘记了你的钱包，你将会丢失你的&lt;b&gt;密码，并且会丢失你的&lt;/b&gt;比特币。</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">您确定要加密您的钱包吗?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">钱包加密</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">输入钱包的新密码，&lt;br/&gt;请使用&lt;b&gt;10个或以上随机字符的密码&lt;/b&gt;，&lt;b&gt;或者8个以上的复杂单词&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">输入钱包的旧密码和新密码。</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">注意，加密你的钱包并不能完全保护你的比特币免受感染你电脑的恶意软件的窃取。</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">加密钱包</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">你的钱包要被加密了。</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">你的钱包现在被加密了。</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">重要提示:您之前对钱包文件所做的任何备份都应该替换为新生成的加密钱包文件。出于安全原因，一旦开始使用新的加密钱包，以前未加密钱包文件的备份就会失效。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">钱包加密失败</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">由于内部错误，钱包加密失败。你的钱包没有加密成功。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">提供的密码不匹配。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">钱包打开失败</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">钱包解密输入的密码不正确。</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">输入的密码有误，无法解密钱包。输入的密码中包含空字符（例如，一个值为零的字节）。如果密码是在此软件早于25.0的版本上设置的，请只输入密码中首个空字符（不包括空字符本身）之前的部分来再尝试一次。如果这样可以成功解密，为避免未来出现问题，请设置一个新的密码。</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">钱包密码更改成功。</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">修改密码失败</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">输入的旧密码有误，无法解密钱包。输入的密码中包含空字符（例如，一个值为零的字节）。如果密码是在此软件早于25.0的版本上设置的，请只输入密码中首个空字符（不包括空字符本身）之前的部分来再尝试一次。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">警告:大写锁定键已打开!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/子网掩码</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">被禁止直到</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">设置文件%1可能已损坏或无效。</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">失控的例外</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">发生了一个致命错误。%1不能再安全地继续并将退出。</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">内部错误</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">发生内部错误。%1将尝试安全继续。这是一个意外的错误，可以报告如下所述。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">要将设置重置为默认值，还是不做任何更改就中止?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">发生了一个致命错误。检查设置文件是否可写，或者尝试使用-nosettings运行。</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">错误: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1尚未安全退出…</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n秒</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n分钟</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n 小时</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n 天</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n 周</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n年</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">最小化</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;文件</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;设置</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;帮助</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">标签工具栏</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">请求支付 (生成二维码和 bitcoin: URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">显示用过的付款地址和标签的列表</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">显示用过的收款地址和标签的列表</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">命令行选项(&amp;C)</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>已處裡%n個區塊的交易紀錄</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">落后 %1</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">最新接收到的区块是在%1之前生成的。</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">在此之后的交易尚不可见。</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">警告</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">信息</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">已是最新</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">從剪貼簿載入PSBT</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">结点窗口</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">打开结点的调试和诊断控制台</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;发送地址</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;接受地址</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">打开比特币: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">打开钱包</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">打开一个钱包</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">关闭钱包</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">恢復錢包...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">從備份檔案中恢復錢包</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">迁移钱包</translation>
    </message>
    <message>
        <source>Migrate a wallet</source>
        <translation type="unfinished">迁移一个钱包</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">显示%1帮助消息以获得可能包含Bitcoin命令行选项的列表</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">无可用钱包</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">載入錢包備份</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">恢復錢包</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;窗口</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">缩放</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">主窗口</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 客户端</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">隐藏(&amp;H)</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">&amp;顯示</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform> %n 与比特币网络接。</numerusform>
        </translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">預先同步標頭(%1%)</translation>
    </message>
    <message>
        <source>Error creating wallet</source>
        <translation type="unfinished">创建钱包时出错</translation>
    </message>
    <message>
        <source>Cannot create new wallet, the software was compiled without sqlite support (required for descriptor wallets)</source>
        <translation type="unfinished">无法创建新钱包，软件编译时未启用SQLite支持（输出描述符钱包需要它）</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">错误: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">警告: %1</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">金額: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">種類: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">標記: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">地址: %1
</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">收款交易</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">產生 HD 金鑰&lt;b&gt;已經啟用&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">HD密钥生成&lt;b&gt;禁用&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">私钥&lt;b&gt;禁用&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">錢包&lt;b&gt;已加密&lt;/b&gt;並且&lt;b&gt;解鎖中&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">原消息:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">金额单位。单击选择别的单位。</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">手动选币</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">复制金额</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">複製交易&amp;ID與輸出序號</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">复制手续费</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(无标签)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">正在创建钱包&lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">偵測到的外接簽名器過多</translation>
    </message>
</context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrate wallet</source>
        <translation type="unfinished">迁移钱包</translation>
    </message>
    <message>
        <source>Are you sure you wish to migrate the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">您确定想要迁移钱包&lt;i&gt;%1&lt;/i&gt;吗？</translation>
    </message>
    <message>
        <source>Migrating the wallet will convert this wallet to one or more descriptor wallets. A new wallet backup will need to be made.
If this wallet contains any watchonly scripts, a new wallet will be created which contains those watchonly scripts.
If this wallet contains any solvable but not watched scripts, a different and new wallet will be created which contains those scripts.

The migration process will create a backup of the wallet before migrating. This backup file will be named &lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak and can be found in the directory for this wallet. In the event of an incorrect migration, the backup can be restored with the "Restore Wallet" functionality.</source>
        <translation type="unfinished">迁移钱包将会把这个钱包转换成一个或多个输出描述符钱包。将会需要创建一个新的钱包备份。
如果这个钱包包含仅观察脚本，将会创建包含那些仅观察脚本的新钱包。
如果这个钱包包含可解但又未被监视的脚本，将会创建一个不同的钱包以包含那些脚本。

迁移过程开始前将会创建一个钱包备份。备份文件将会被命名为 &lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak 然后被保存在该钱包所在目录下。如果迁移过程出错，可以使用“恢复钱包”功能恢复备份。</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">迁移钱包</translation>
    </message>
    <message>
        <source>Migrating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <translation type="unfinished">迁移钱包 &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>The wallet '%1' was migrated successfully.</source>
        <translation type="unfinished">已成功迁移钱包 '%1' 。</translation>
    </message>
    <message>
        <source> Watchonly scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished">仅观察脚本已被迁移至名为 '%1' 的新钱包中。</translation>
    </message>
    <message>
        <source> Solvable but not watched scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished"> 可解但又未被监视的脚本已被迁移至名为 '%1' 的新钱包中。</translation>
    </message>
    <message>
        <source>Migration failed</source>
        <translation type="unfinished">迁移失败</translation>
    </message>
    <message>
        <source>Migration Successful</source>
        <translation type="unfinished">迁移成功</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">默认钱包</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">打开钱包</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">恢復錢包</translation>
    </message>
    <message>
        <source>Restoring Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.</extracomment>
        <translation type="unfinished">正在恢復錢包&lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">恢復錢包失敗</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">恢復錢包警告</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">恢復錢包訊息</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">关闭钱包</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">启用修剪时，如果一个钱包被卸载太久，就必须重新同步整条区块链才能再次加载它。</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>You are one step away from creating your new wallet!</source>
        <translation type="unfinished">距离创建您的新钱包只有一步之遥了！</translation>
    </message>
    <message>
        <source>Please provide a name and, if desired, enable any advanced options</source>
        <translation type="unfinished">请指定一个名字，如果需要的话还可以启用高级选项</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">进阶设定</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">禁用私钥</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">编辑地址</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">标签(&amp;L)</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">与此地址关联的标签</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">新建付款地址</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">编辑付款地址</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">输入的地址“%1”已经存在于地址簿中，标签为“%2”。</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">无法解锁钱包。</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">无法在此创建数据目录。</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%nGB可用</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(需要 %n GB)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>（完整區塊鏈需要%n GB）</numerusform>
        </translation>
    </message>
    <message>
        <source>Choose data directory</source>
        <translation type="unfinished">选择数据目录</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">错误</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation type="unfinished">初始化同步过程是非常吃力的，同时可能会暴露您之前没有注意到的电脑硬件问题。你每次启动%1时，它都会从之前中断的地方继续下载。</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2 GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation type="unfinished">當你點擊「確認」，%1會開始下載，並從%3年最早的交易，處裡整個%4區塊鏈(大小:%2GB)</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Unknown. Pre-syncing Headers (%1, %2%)…</source>
        <translation type="unfinished">不明。正在預先同步標頭(%1, %2%)...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
        <translation type="unfinished">与%1兼容的脚本文件路径（例如 C:\Downloads\hwi.exe 或者 /Users/you/Downloads/hwi.py ）。注意：恶意软件可以偷币！</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">这个对话框中的设置已被如下命令行选项覆盖:</translation>
    </message>
    <message>
        <source>Maximum database cache size. A larger cache can contribute to faster sync, after which the benefit is less pronounced for most use cases. Lowering the cache size will reduce memory usage. Unused mempool memory is shared for this cache.</source>
        <extracomment>Tooltip text for Options window setting that sets the size of the database cache. Explains the corresponding effects of increasing/decreasing this value.</extracomment>
        <translation type="unfinished">数据库缓存的最大大小。加大缓存有助于加快同步，但对于大多数使用场景来说，继续加大后收效会越来越不明显。降低缓存大小将会减小内存使用量。内存池中尚未被使用的那部分内存也会被共享用于这里的数据库缓存。</translation>
    </message>
    <message>
        <source>Set the number of script verification threads. Negative values correspond to the number of cores you want to leave free to the system.</source>
        <extracomment>Tooltip text for Options window setting that sets the number of script verification threads. Explains that negative values mean to leave these many cores free to the system.</extracomment>
        <translation type="unfinished">设置脚本验证线程的数量。负值则表示你想要保留给系统的核心数量。</translation>
    </message>
    <message>
        <source>This allows you or a third party tool to communicate with the node through command-line and JSON-RPC commands.</source>
        <extracomment>Tooltip text for Options window setting that enables the RPC server.</extracomment>
        <translation type="unfinished">这允许作为用户的你或第三方工具通过命令行和JSON-RPC命令行与节点通信。</translation>
    </message>
    <message>
        <source>Enable R&amp;PC server</source>
        <extracomment>An Options window setting to enable the RPC server.</extracomment>
        <translation type="unfinished">启用R&amp;PC服务器</translation>
    </message>
    <message>
        <source>Whether to set subtract fee from amount as default or not.</source>
        <extracomment>Tooltip text for Options window setting that sets subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">是否要默认从金额中减去手续费。</translation>
    </message>
    <message>
        <source>Subtract &amp;fee from amount by default</source>
        <extracomment>An Options window setting to set subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">默认从金额中减去交易手续费(&amp;F)</translation>
    </message>
    <message>
        <source>Enable &amp;PSBT controls</source>
        <extracomment>An options window setting to enable PSBT controls.</extracomment>
        <translation type="unfinished">启用&amp;PSBT控件</translation>
    </message>
    <message>
        <source>Whether to show PSBT controls.</source>
        <extracomment>Tooltip text for options window setting that enables PSBT controls.</extracomment>
        <translation type="unfinished">是否要显示PSBT控件</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;窗口</translation>
    </message>
    <message>
        <source>Third-party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation type="unfinished">这个第三方网址（比如区块浏览器）会出现在交易选项卡的右键菜单中。 网址中的%s代表交易哈希。多个网址需要用竖线 | 相互分隔。</translation>
    </message>
    <message>
        <source>&amp;Third-party transaction URLs</source>
        <translation type="unfinished">第三方交易网址(&amp;T)</translation>
    </message>
    <message>
        <source>Current settings will be backed up at "%1".</source>
        <extracomment>Text explaining to the user that the client's current settings will be backed up at a specific location. %1 is a stand-in argument for the backup location's path.</extracomment>
        <translation type="unfinished">当前设置将会被备份到 "%1"。</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">继续</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">错误</translation>
    </message>
    </context>
<context>
    <name>OptionsModel</name>
    <message>
        <source>Could not read setting "%1", %2.</source>
        <translation type="unfinished">无法读取设置 "%1"，%2。</translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>PSBT Operations</source>
        <translation type="unfinished">PSBT操作</translation>
    </message>
    <message>
        <source>Cannot sign inputs while wallet is locked.</source>
        <translation type="unfinished">钱包已锁定，无法签名交易输入项。</translation>
    </message>
    <message>
        <source>(But no wallet is loaded.)</source>
        <translation type="unfinished">(但没有加载钱包。)</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">连接时间</translation>
    </message>
    <message>
        <source>Direction</source>
        <extracomment>Title of Peers Table column which indicates the direction the peer connection was initiated from.</extracomment>
        <translation type="unfinished">方向</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">地址</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>The transport layer version: %1</source>
        <translation type="unfinished">传输层版本: %1</translation>
    </message>
    <message>
        <source>Transport</source>
        <translation type="unfinished">传输</translation>
    </message>
    <message>
        <source>The BIP324 session ID string in hex, if any.</source>
        <translation type="unfinished">十六进制格式的BIP324会话ID，如果有的话。</translation>
    </message>
    <message>
        <source>Session ID</source>
        <translation type="unfinished">会话ID</translation>
    </message>
    <message>
        <source>Whether we relay transactions to this peer.</source>
        <translation type="unfinished">是否要将交易转发给这个节点。</translation>
    </message>
    <message>
        <source>Transaction Relay</source>
        <translation type="unfinished">交易转发</translation>
    </message>
    <message>
        <source>Last Transaction</source>
        <translation type="unfinished">最近交易</translation>
    </message>
    <message>
        <source>Whether we relay addresses to this peer.</source>
        <extracomment>Tooltip text for the Address Relay field in the peer details area, which displays whether we relay addresses to this peer (Yes/No).</extracomment>
        <translation type="unfinished">是否把地址转发给这个节点。</translation>
    </message>
    <message>
        <source>Address Relay</source>
        <extracomment>Text title for the Address Relay field in the peer details area, which displays whether we relay addresses to this peer (Yes/No).</extracomment>
        <translation type="unfinished">地址转发</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</source>
        <extracomment>Tooltip text for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">从这个节点接收并处理过的地址总数（除去因频次限制而丢弃的那些地址）。</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</source>
        <extracomment>Tooltip text for the Addresses Rate-Limited field in the peer details area, which displays the total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</extracomment>
        <translation type="unfinished">从这个节点接收后又因频次限制而丢弃（未被处理）的地址总数。</translation>
    </message>
    <message>
        <source>Addresses Processed</source>
        <extracomment>Text title for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">已处理地址</translation>
    </message>
    <message>
        <source>Addresses Rate-Limited</source>
        <extracomment>Text title for the Addresses Rate-Limited field in the peer details area, which displays the total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</extracomment>
        <translation type="unfinished">被频率限制丢弃的地址</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">结点窗口</translation>
    </message>
    <message>
        <source>detecting: peer could be v1 or v2</source>
        <extracomment>Explanatory text for "detecting" transport type.</extracomment>
        <translation type="unfinished">检测中: 节点可能是v1或是v2</translation>
    </message>
    <message>
        <source>v1: unencrypted, plaintext transport protocol</source>
        <extracomment>Explanatory text for v1 transport type.</extracomment>
        <translation type="unfinished">v1: 未加密，明文传输协议</translation>
    </message>
    <message>
        <source>v2: BIP324 encrypted transport protocol</source>
        <extracomment>Explanatory text for v2 transport type.</extracomment>
        <translation type="unfinished">v2: BIP324加密传输协议</translation>
    </message>
    <message>
        <source>&amp;Copy IP/Netmask</source>
        <extracomment>Context menu action to copy the IP/Netmask of a banned peer. IP/Netmask is the combination of a peer's IP address and its Netmask. For IP address, see: https://en.wikipedia.org/wiki/IP_address.</extracomment>
        <translation type="unfinished">复制IP/网络掩码(&amp;C)</translation>
    </message>
    <message>
        <source>Welcome to the %1 RPC console.
Use up and down arrows to navigate history, and %2 to clear screen.
Use %3 and %4 to increase or decrease the font size.
Type %5 for an overview of available commands.
For more information on using this console, type %6.

%7WARNING: Scammers have been active, telling users to type commands here, stealing their wallet contents. Do not use this console without fully understanding the ramifications of a command.%8</source>
        <extracomment>RPC console welcome message. Placeholders %7 and %8 are style tags for the warning content, and they are not space separated from the rest of the text intentionally.</extracomment>
        <translation type="unfinished">欢迎来到 %1 RPC 控制台。
使用上与下箭头以进行历史导航，%2 以清除屏幕。
使用%3 和 %4 以增加或减小字体大小。
输入 %5 以显示可用命令的概览。
查看更多关于此控制台的信息，输入 %6。

%7 警告：骗子们很活跃，他们会让用户在这里输入命令以便偷走用户钱包中的内容。所以请您不要在不完全了解一个命令的后果的情况下使用此控制台。%8</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Base58 (Legacy)</source>
        <translation type="unfinished">Base58 (旧式)</translation>
    </message>
    <message>
        <source>Not recommended due to higher fees and less protection against typos.</source>
        <translation type="unfinished">因手续费较高，而且打字错误防护较弱，故不推荐。</translation>
    </message>
    <message>
        <source>Generates an address compatible with older wallets.</source>
        <translation type="unfinished">生成一个与旧版钱包兼容的地址。</translation>
    </message>
    <message>
        <source>Generates a native segwit address (BIP-173). Some old wallets don't support it.</source>
        <translation type="unfinished">生成一个原生隔离见证地址 (BIP-173) 。不被部分旧版本钱包所支持。</translation>
    </message>
    <message>
        <source>Bech32m (BIP-350) is an upgrade to Bech32, wallet support is still limited.</source>
        <translation type="unfinished">Bech32m (BIP-350) 是对 Bech32 的更新升级，支持它的钱包仍然比较有限。</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">无法解锁钱包。</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(无标签)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">复制金额</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">复制手续费</translation>
    </message>
    <message>
        <source>Do you want to create this transaction?</source>
        <extracomment>Message displayed when attempting to create a transaction. Cautionary text to prompt the user to verify that the displayed transaction details represent the transaction the user intends to create.</extracomment>
        <translation type="unfinished">要创建这笔交易吗？</translation>
    </message>
    <message>
        <source>Please, review your transaction. You can create and send this transaction or create a Partially Signed Bitcoin Transaction (PSBT), which you can save or copy and then sign with, e.g., an offline %1 wallet, or a PSBT-compatible hardware wallet.</source>
        <extracomment>Text to inform a user attempting to create a transaction of their current options. At this stage, a user can send their transaction or create a PSBT. This string is displayed when both private keys and PSBT controls are enabled.</extracomment>
        <translation type="unfinished">请务必仔细检查您的交易。你可以创建并发送这笔交易；也可以创建一个“部分签名比特币交易(PSBT)”，它可以被保存下来或被复制出去，然后就可以对它进行签名，比如用离线%1钱包，或是用兼容PSBT的硬件钱包。</translation>
    </message>
    <message>
        <source>Unsigned Transaction</source>
        <comment>PSBT copied</comment>
        <extracomment>Caption of "PSBT has been copied" messagebox</extracomment>
        <translation type="unfinished">未签名交易</translation>
    </message>
    <message>
        <source>The PSBT has been copied to the clipboard. You can also save it.</source>
        <translation type="unfinished">PSBT已被复制到剪贴板。您也可以保存它。</translation>
    </message>
    <message>
        <source>PSBT saved to disk</source>
        <translation type="unfinished">PSBT已保存到磁盘</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>预计%n个区块内确认。</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(无标签)</translation>
    </message>
</context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Send</source>
        <translation type="unfinished">发送</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>(press q to shutdown and continue later)</source>
        <translation type="unfinished">(按q退出并在以后继续)</translation>
    </message>
    <message>
        <source>press q to shutdown</source>
        <translation type="unfinished">按q键关闭并退出</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>0/unconfirmed, in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is in the memory pool.</extracomment>
        <translation type="unfinished">0/未确认，在内存池中</translation>
    </message>
    <message>
        <source>0/unconfirmed, not in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is not in the memory pool.</extracomment>
        <translation type="unfinished">0/未确认，不在内存池中</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>在%n个区块内成熟</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(无标签)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Show in %1</source>
        <extracomment>Transactions table context menu action to show the selected transaction in a third-party block explorer. %1 is a stand-in argument for the URL of the explorer.</extracomment>
        <translation type="unfinished">在 %1中显示</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">逗号分隔文件</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">导出失败</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">错误</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Copied to clipboard</source>
        <comment>Fee-bump PSBT saved</comment>
        <translation type="unfinished">复制到剪贴板</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">默认钱包</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">导出(&amp;E)</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">将当前选项卡中的数据导出到文件</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>%s failed to validate the -assumeutxo snapshot state. This indicates a hardware problem, or a bug in the software, or a bad software modification that allowed an invalid snapshot to be loaded. As a result of this, the node will shut down and stop using any state that was built on the snapshot, resetting the chain height from %d to %d. On the next restart, the node will resume syncing from %d without using any snapshot data. Please report this incident to %s, including how you obtained the snapshot. The invalid snapshot chainstate will be left on disk in case it is helpful in diagnosing the issue that caused this error.</source>
        <translation type="unfinished">%s 验证 -assumeutxo 快照状态失败。这表明硬件可能有问题，也可能是软件bug，或者还可能是软件被不当修改、从而让非法快照也能够被加载。因此，将关闭节点并停止使用从这个快照构建出的任何状态，并将链高度从 %d 重置到 %d 。下次启动时，节点将会不使用快照数据从 %d 继续同步。请将这个事件报告给 %s 并在报告中包括您是如何获得这份快照的。无效的链状态快照仍被保存至磁盘上，以供诊断问题的原因。</translation>
    </message>
    <message>
        <source>%s request to listen on port %u. This port is considered "bad" and thus it is unlikely that any peer will connect to it. See doc/p2p-bad-ports.md for details and a full list.</source>
        <translation type="unfinished">%s请求监听端口%u。此端口被认为是“坏的”，所以不太可能有其他节点会连接过来。详情以及完整的端口列表请参见 doc/p2p-bad-ports.md 。</translation>
    </message>
    <message>
        <source>Disk space for %s may not accommodate the block files. Approximately %u GB of data will be stored in this directory.</source>
        <translation type="unfinished">%s的磁盘空间可能无法容纳区块文件。大约要在这个目录中储存 %uGB 的数据。</translation>
    </message>
    <message>
        <source>Error loading wallet. Wallet requires blocks to be downloaded, and software does not currently support loading wallets while blocks are being downloaded out of order when using assumeutxo snapshots. Wallet should be able to load successfully after node sync reaches height %s</source>
        <translation type="unfinished">加载钱包时出错。需要下载区块才能加载钱包，而且在使用assumeutxo快照时，下载区块是不按顺序的，这个时候软件不支持加载钱包。在节点同步至高度%s之后就应该可以加载钱包了。</translation>
    </message>
    <message>
        <source>Error reading %s! Transaction data may be missing or incorrect. Rescanning wallet.</source>
        <translation type="unfinished">读取%s出错！交易数据可能丢失或有误。重新扫描钱包中。</translation>
    </message>
    <message>
        <source>Error: Legacy wallets only support the "legacy", "p2sh-segwit", and "bech32" address types</source>
        <translation type="unfinished">错误: 旧式钱包只支持 "legacy", "p2sh-segwit", 和 "bech32" 这三种地址类型</translation>
    </message>
    <message>
        <source>Error: Unable to produce descriptors for this legacy wallet. Make sure to provide the wallet's passphrase if it is encrypted.</source>
        <translation type="unfinished">错误: 无法为该旧式钱包生成描述符。如果钱包已被加密，请确保提供的钱包加密密码正确。</translation>
    </message>
    <message>
        <source>Invalid or corrupt peers.dat (%s). If you believe this is a bug, please report it to %s. As a workaround, you can move the file (%s) out of the way (rename, move, or delete) to have a new one created on the next start.</source>
        <translation type="unfinished">无效或损坏的peers.dat (%s)。如果你确信这是一个bug，请反馈到%s。作为变通办法，你可以把现有文件 (%s) 移开(重命名、移动或删除)，这样就可以在下次启动时创建一个新文件了。</translation>
    </message>
    <message>
        <source>Prune mode is incompatible with -reindex-chainstate. Use full -reindex instead.</source>
        <translation type="unfinished">修剪模式与 -reindex-chainstate 不兼容。请进行一次完整的 -reindex 。</translation>
    </message>
    <message>
        <source>Rename of '%s' -&gt; '%s' failed. You should resolve this by manually moving or deleting the invalid snapshot directory %s, otherwise you will encounter the same error again on the next startup.</source>
        <translation type="unfinished">重命名 '%s' -&gt; '%s' 失败。您需要手动移走或删除无效的快照目录 %s来解决这个问题，不然的话您就会在下一次启动时遇到相同的错误。</translation>
    </message>
    <message>
        <source>Unsupported category-specific logging level %1$s=%2$s. Expected %1$s=&lt;category&gt;:&lt;loglevel&gt;. Valid categories: %3$s. Valid loglevels: %4$s.</source>
        <translation type="unfinished">不支持的类别限定日志等级 %1$s=%2$s 。 预期参数 %1$s=&lt;category&gt;:&lt;loglevel&gt;。 有效的类别: %3$s 。有效的日志等级: %4$s 。</translation>
    </message>
    <message>
        <source>Unsupported chainstate database format found. Please restart with -reindex-chainstate. This will rebuild the chainstate database.</source>
        <translation type="unfinished">找到了不受支持的 chainstate 数据库格式。请使用 -reindex-chainstate 参数重启。这将会重建 chainstate 数据库。</translation>
    </message>
    <message>
        <source>Wallet created successfully. The legacy wallet type is being deprecated and support for creating and opening legacy wallets will be removed in the future.</source>
        <translation type="unfinished">钱包创建成功。旧式钱包已被弃用，未来将不再支持创建或打开旧式钱包。</translation>
    </message>
    <message>
        <source>Wallet loaded successfully. The legacy wallet type is being deprecated and support for creating and opening legacy wallets will be removed in the future. Legacy wallets can be migrated to a descriptor wallet with migratewallet.</source>
        <translation type="unfinished">钱包加载成功。旧式钱包已被弃用，未来将不再支持创建或打开旧式钱包。可以使用 migratewallet 命令将旧式钱包迁移至输出描述符钱包。</translation>
    </message>
    <message>
        <source>Cannot set -forcednsseed to true when setting -dnsseed to false.</source>
        <translation type="unfinished">在 -dnsseed 被设为 false 时无法将 -forcednsseed 设为 true 。</translation>
    </message>
    <message>
        <source>%s is set very high! Fees this large could be paid on a single transaction.</source>
        <translation type="unfinished">%s被设置得很高! 这可是一次交易就有可能付出的手续费。</translation>
    </message>
    <message>
        <source>Cannot provide specific connections and have addrman find outgoing connections at the same time.</source>
        <translation type="unfinished">在使用地址管理器(addrman)寻找出站连接时，无法同时提供特定的连接。</translation>
    </message>
    <message>
        <source>Error loading %s: External signer wallet being loaded without external signer support compiled</source>
        <translation type="unfinished">加载%s时出错: 编译时未启用外部签名器支持，却仍然试图加载外部签名器钱包</translation>
    </message>
    <message>
        <source>Error reading %s! All keys read correctly, but transaction data or address metadata may be missing or incorrect.</source>
        <translation type="unfinished">读取 %s 时出错! 所有密钥都被正确读取，但交易数据或地址元数据可能缺失或有误。</translation>
    </message>
    <message>
        <source>Error: Address book data in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">错误：钱包中的地址簿数据无法被识别为属于迁移后的钱包</translation>
    </message>
    <message>
        <source>Error: Duplicate descriptors created during migration. Your wallet may be corrupted.</source>
        <translation type="unfinished">错误：迁移过程中创建了重复的输出描述符。你的钱包可能已损坏。</translation>
    </message>
    <message>
        <source>Error: Transaction %s in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">错误：钱包中的交易%s无法被识别为属于迁移后的钱包</translation>
    </message>
    <message>
        <source>Failed to calculate bump fees, because unconfirmed UTXOs depend on enormous cluster of unconfirmed transactions.</source>
        <translation type="unfinished">计算追加手续费失败，因为未确认UTXO依赖了大量未确认交易的簇集。</translation>
    </message>
    <message>
        <source>Failed to rename invalid peers.dat file. Please move or delete it and try again.</source>
        <translation type="unfinished">无法重命名无效的 peers.dat 文件。 请移动或删除它，然后重试。</translation>
    </message>
    <message>
        <source>Fee estimation failed. Fallbackfee is disabled. Wait a few blocks or enable %s.</source>
        <translation type="unfinished">手续费估计失败。而且备用手续费估计（fallbackfee）已被禁用。请再等一些区块，或者启用%s。</translation>
    </message>
    <message>
        <source>Incompatible options: -dnsseed=1 was explicitly specified, but -onlynet forbids connections to IPv4/IPv6</source>
        <translation type="unfinished">互不兼容的选项：-dnsseed=1 已被显式指定，但 -onlynet 禁止了IPv4/IPv6 连接</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s' (must be at least the minrelay fee of %s to prevent stuck transactions)</source>
        <translation type="unfinished">%s=&lt;amount&gt;: '%s' 中指定了非法的金额 (手续费必须至少达到最小转发费率(minrelay fee) %s 以避免交易卡着发不出去)</translation>
    </message>
    <message>
        <source>Outbound connections restricted to CJDNS (-onlynet=cjdns) but -cjdnsreachable is not provided</source>
        <translation type="unfinished">传出连接被限制为仅使用CJDNS (-onlynet=cjdns) ，但却未提供 -cjdnsreachable 参数。</translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is explicitly forbidden: -onion=0</source>
        <translation type="unfinished">出站连接被限制为仅使用 Tor (-onlynet=onion)，但是到达 Tor 网络的代理被显式禁止： -onion=0</translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is not provided: none of -proxy, -onion or -listenonion is given</source>
        <translation type="unfinished">出站连接被限制为仅使用 Tor (-onlynet=onion)，但是未提供到达 Tor 网络的代理：没有提供 -proxy=, -onion= 或 -listenonion 参数</translation>
    </message>
    <message>
        <source>Outbound connections restricted to i2p (-onlynet=i2p) but -i2psam is not provided</source>
        <translation type="unfinished">传出连接被限制为仅使用I2P (-onlynet=i2p) ，但却未提供 -i2psam 参数。</translation>
    </message>
    <message>
        <source>The inputs size exceeds the maximum weight. Please try sending a smaller amount or manually consolidating your wallet's UTXOs</source>
        <translation type="unfinished">输入大小超出了最大重量。请尝试减少发出的金额，或者手动整合一下钱包UTXO</translation>
    </message>
    <message>
        <source>The preselected coins total amount does not cover the transaction target. Please allow other inputs to be automatically selected or include more coins manually</source>
        <translation type="unfinished">预先选择的币总金额不能覆盖交易目标。请允许自动选择其他输入，或者手动加入更多的币</translation>
    </message>
    <message>
        <source>Transaction requires one destination of non-0 value, a non-0 feerate, or a pre-selected input</source>
        <translation type="unfinished">交易要求一个非零值目标，或是非零值手续费率，或是预选中的输入。</translation>
    </message>
    <message>
        <source>UTXO snapshot failed to validate. Restart to resume normal initial block download, or try loading a different snapshot.</source>
        <translation type="unfinished">验证UTXO快照失败。重启后，可以普通方式继续初始区块下载，或者也可以加载一个不同的快照。</translation>
    </message>
    <message>
        <source>Unconfirmed UTXOs are available, but spending them creates a chain of transactions that will be rejected by the mempool</source>
        <translation type="unfinished">未确认UTXO可用，但花掉它们将会创建一条会被内存池拒绝的交易链</translation>
    </message>
    <message>
        <source>Unexpected legacy entry in descriptor wallet found. Loading wallet %s

The wallet might have been tampered with or created with malicious intent.
</source>
        <translation type="unfinished">在描述符钱包中意料之外地找到了旧式条目。加载钱包%s

钱包可能被篡改过，或者是出于恶意而被构建的。
</translation>
    </message>
    <message>
        <source>Unrecognized descriptor found. Loading wallet %s

The wallet might had been created on a newer version.
Please try running the latest software version.
</source>
        <translation type="unfinished">找到无法识别的输出描述符。加载钱包%s

钱包可能由新版软件创建，
请尝试运行最新的软件版本。
</translation>
    </message>
    <message>
        <source>
Unable to cleanup failed migration</source>
        <translation type="unfinished">
无法清理失败的迁移</translation>
    </message>
    <message>
        <source>
Unable to restore backup of wallet.</source>
        <translation type="unfinished">
无法还原钱包备份</translation>
    </message>
    <message>
        <source>Block verification was interrupted</source>
        <translation type="unfinished">区块验证已中断</translation>
    </message>
    <message>
        <source>Error reading configuration file: %s</source>
        <translation type="unfinished">读取配置文件失败: %s</translation>
    </message>
    <message>
        <source>Error: Cannot extract destination from the generated scriptpubkey</source>
        <translation type="unfinished">错误: 无法从生成的scriptpubkey提取目标</translation>
    </message>
    <message>
        <source>Error: Could not add watchonly tx to watchonly wallet</source>
        <translation type="unfinished">错误：无法添加仅观察交易至仅观察钱包</translation>
    </message>
    <message>
        <source>Error: Could not delete watchonly transactions</source>
        <translation type="unfinished">错误：无法删除仅观察交易</translation>
    </message>
    <message>
        <source>Error: Failed to create new watchonly wallet</source>
        <translation type="unfinished">错误：创建新仅观察钱包失败</translation>
    </message>
    <message>
        <source>Error: Not all watchonly txs could be deleted</source>
        <translation type="unfinished">错误：有些仅观察交易无法被删除</translation>
    </message>
    <message>
        <source>Error: This wallet already uses SQLite</source>
        <translation type="unfinished">错误：此钱包已经在使用SQLite</translation>
    </message>
    <message>
        <source>Error: This wallet is already a descriptor wallet</source>
        <translation type="unfinished">错误：这个钱包已经是输出描述符钱包</translation>
    </message>
    <message>
        <source>Error: Unable to begin reading all records in the database</source>
        <translation type="unfinished">错误：无法开始读取这个数据库中的所有记录</translation>
    </message>
    <message>
        <source>Error: Unable to make a backup of your wallet</source>
        <translation type="unfinished">错误：无法为你的钱包创建备份</translation>
    </message>
    <message>
        <source>Error: Unable to read all records in the database</source>
        <translation type="unfinished">错误：无法读取这个数据库中的所有记录</translation>
    </message>
    <message>
        <source>Error: Unable to remove watchonly address book data</source>
        <translation type="unfinished">错误：无法移除仅观察地址簿数据</translation>
    </message>
    <message>
        <source>Failed to start indexes, shutting down..</source>
        <translation type="unfinished">无法启动索引，关闭中...</translation>
    </message>
    <message>
        <source>Input not found or already spent</source>
        <translation type="unfinished">找不到交易項，或可能已經花掉了</translation>
    </message>
    <message>
        <source>Insufficient dbcache for block verification</source>
        <translation type="unfinished">dbcache不足以用于区块验证</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s' (must be at least %s)</source>
        <translation type="unfinished">%s=&lt;amount&gt;: '%s' 中指定了非法的金额 (必须至少达到 %s)</translation>
    </message>
    <message>
        <source>Invalid amount for %s=&lt;amount&gt;: '%s'</source>
        <translation type="unfinished">%s=&lt;amount&gt;: '%s' 中指定了非法的金额</translation>
    </message>
    <message>
        <source>Invalid port specified in %s: '%s'</source>
        <translation type="unfinished">%s指定了无效的端口号: '%s'</translation>
    </message>
    <message>
        <source>Invalid pre-selected input %s</source>
        <translation type="unfinished">无效的预先选择输入%s</translation>
    </message>
    <message>
        <source>Listening for incoming connections failed (listen returned error %s)</source>
        <translation type="unfinished">监听外部连接失败 (listen函数返回了错误 %s)</translation>
    </message>
    <message>
        <source>Missing amount</source>
        <translation type="unfinished">缺少金額</translation>
    </message>
    <message>
        <source>Missing solving data for estimating transaction size</source>
        <translation type="unfinished">缺少用於估計交易規模的求解數據</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">沒有可用的地址</translation>
    </message>
    <message>
        <source>Not found pre-selected input %s</source>
        <translation type="unfinished">找不到预先选择输入%s</translation>
    </message>
    <message>
        <source>Not solvable pre-selected input %s</source>
        <translation type="unfinished">无法求解的预先选择输入%s</translation>
    </message>
    <message>
        <source>Specified data directory "%s" does not exist.</source>
        <translation type="unfinished">指定的数据目录 "%s" 不存在。</translation>
    </message>
    <message>
        <source>Transaction change output index out of range</source>
        <translation type="unfinished">交易尋找零輸出項超出範圍</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it.</source>
        <translation type="unfinished">交易需要一个找零地址，但是我们无法生成它。</translation>
    </message>
    <message>
        <source>Unable to allocate memory for -maxsigcachesize: '%s' MiB</source>
        <translation type="unfinished">无法为 -maxsigcachesize: '%s' MiB 分配内存</translation>
    </message>
    <message>
        <source>Unable to find UTXO for external input</source>
        <translation type="unfinished">无法为外部输入找到UTXO</translation>
    </message>
    <message>
        <source>Unable to parse -maxuploadtarget: '%s'</source>
        <translation type="unfinished">無法解析-最大上傳目標:'%s'</translation>
    </message>
    <message>
        <source>Unable to unload the wallet before migrating</source>
        <translation type="unfinished">在迁移前无法卸载钱包</translation>
    </message>
    <message>
        <source>Unsupported global logging level %s=%s. Valid values: %s.</source>
        <translation type="unfinished">不支持的全局日志等级 %s=%s。有效数值: %s.</translation>
    </message>
    <message>
        <source>acceptstalefeeestimates is not supported on %s chain.</source>
        <translation type="unfinished">%s链上acceptstalefeeestimates 不受支持。</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">无法读取设置文件</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">无法写入设置文件</translation>
    </message>
</context>
</TS>